@@ -93,6 +93,7 @@ correct_names_dict = {
     "NICHOLAS DRAZENOVIC" : "NICK DRAZENOVIC",
     "NICKLAS BERGFORS" : "NICLAS BERGFORS",
     "NICKLAS GROSSMAN" : "NICKLAS GROSSMANN",
+    "NICHOLAS MERKLEY": "NICK MERKLEY",
     "NICOLAS PETAN" : "NIC PETAN",
     "NIKLAS KRONVALL" : "NIKLAS KRONWALL",
     "NIKOLAI ANTROPOV" : "NIK ANTROPOV",
@@ -193,6 +194,9 @@ correct_names_dict = {
     "TREVOR VAN RIEMSDYK" : "TREVOR VAN RIEMSDYK",
     "ZACK FITZGERALD" : "ZACH FITZGERALD",
     "THOMAS DI PAULI" : "THOMAS DI PAULI",
+    "WILLIAM BORGEN": "WILL BORGEN",
+    "ALEXANDER CHMELEVSKI": "SASHA CHMELEVSKI",
+    "ALEX CHMELEVSKI": "SASHA CHMELEVSKI",
                 }
 
 api_names_dict = {
