@@ -92,14 +92,10 @@ def convert_to_list(obj):
     
     return obj
 
-def update_prop(handle, orig, marker_size = 250):
-    handle.update_from(orig)
-    handle.set_sizes([marker_size])
-
 ############################################## One-game rink map function ##############################################
 
 def game_rink_map(data, good_team = None, title = None, size = None, strengths = ['all', '5v5', 'PP', 'SH', 'EV', '3v3'],
-                        colors = None, save_img = False, annotations = False, default_colors = NHL_COLORS, size_multiplier = 500):
+                        colors = None, save_img = False, annotations = True, default_colors = NHL_COLORS, size_multiplier = 50):
     
     '''
     Function to normalize coordinates to one zone
@@ -316,7 +312,7 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
                     
                 else:
                     
-                    s = event_df[size] * size_multiplier
+                    s = 0.3 * (event_df[size] * size_multiplier) ** 2
                 
                 sc = rink.scatter(event_df.norm_coords_x, event_df.norm_coords_y, c = color, label = result, s = s, alpha = 0.8,
                                 ax = ax, edgecolors = edge_color, is_constrained = True, zorder = zorder_dict[result])
@@ -332,7 +328,7 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
                             
                             ax.annotate(event_df['event_player_1'][idx],
                                         (event_df['new_x'][idx], event_df['new_y'][idx]),
-                                        bbox=dict(boxstyle = 'round', fc = 'white', ec = 'gray', alpha = 0.675)
+                                        bbox=dict(boxstyle = 'round', fc = 'white', ec = 'gray', alpha = 0.65)
                                        ).set_zorder(1000)
                     
                     #for i in range(len(x)):
@@ -355,7 +351,7 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
 
                     legend_elements = list()
 
-                    for result, color in colors[team].items():
+                    for result, color in colors_dict.items():
 
                         if result == 'GOAL':
 
@@ -366,20 +362,10 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
                             edge_color = color
 
                         element = Line2D([0], [0], markeredgecolor = edge_color, marker = 'o', markerfacecolor = color,
-                                    label = result, markersize = 14, color = 'w')
+                                    label = result, markersize = 14, color = 'w', alpha = 0.8)
 
                         legend_elements.append(element)
 
-
-                #legend_elements = [Line2D([0], [0], markeredgecolor = colors[team]['SHOT'], marker = 'o',
-                #                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 14, color = 'w',),
-                #                    
-                #                    Line2D([0], [0], marker='o', markeredgecolor = colors[team]['SHOT'], label= 'SHOT',
-                #                        color = 'w', markerfacecolor = colors[team]['SHOT'], markersize = 14),
-                #
-                #                   Line2D([0], [0], marker='o', color = colors[team]['MISS'], label= 'MISS',
-                #                    markerfacecolor = colors[team]['MISS'], markersize = 14, color = 'w',)]
-
                     legend = ax.legend(handles = legend_elements, loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
                                         title_fontsize = 16, facecolor = 'white', framealpha = 1,
                                         edgecolor = 'gray').set_zorder(-1)
@@ -395,8 +381,8 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
                 else:
 
                     legend_elements = list()
-                    
-                    for result, color in colors[team].items():
+
+                    for result, color in colors_dict.items():
 
                         if result == 'GOAL':
 
@@ -407,20 +393,10 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
                             edge_color = color
 
                         element = Line2D([0], [0], markeredgecolor = edge_color, marker = 'o', markerfacecolor = color,
-                                    label = result, markersize = 14, color = 'w')
+                                    label = result, markersize = 14, color = 'w', alpha = 0.8)
 
                         legend_elements.append(element)
 
-
-                #legend_elements = [Line2D([0], [0], markeredgecolor = colors[team]['SHOT'], marker = 'o',
-                #                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 14, color = 'w',),
-                #                    
-                #                    Line2D([0], [0], marker='o', markeredgecolor = colors[team]['SHOT'], label= 'SHOT',
-                #                       markerfacecolor = colors[team]['SHOT'], markersize = 14, color = 'w',),
-                #
-                #                   Line2D([0], [0], marker='o', markeredgecolor = colors[team]['MISS'], label= 'MISS',
-                #                    markerfacecolor = colors[team]['MISS'], markersize = 14, color = 'w',)]
-
                     legend = ax.legend(handles = legend_elements, loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
                                         title_fontsize = 16, facecolor = 'white', framealpha = 1,
                                         edgecolor = 'gray').set_zorder(-1)
